.. _tutorials:

Tutorials
=========

The following tutorials walk you through performing orbit fits with
``orbitize``. To get started, read through "Formatting Input," "OFTI
Introduction," and "MCMC Introduction." To learn more about the 
``orbitize`` API, check out "Modifying Priors" and "Modifying MCMC Initial Positions."
For an advanced plotting demo, see "Advanced Plotting," and to learn 
about the differences between OFTI and MCMC algorithms,
we suggest "MCMC vs OFTI Comparison."

Many of these tutorials are also available as jupyter notebooks 
`here <https://github.com/sblunt/orbitize/tree/master/docs>`_.

If you find a bug, or if something is unclear, please create an issue
on GitHub! We'd love any feedback on how to make ``orbitize`` more
accessible.

*A note about the tutorials*: There are many ways to interact with the
``orbitize`` code base, and each person on our team uses the code differently.
Each tutorial has a different author, and correspondingly a different 
style of using and explaining the code. If you are confused by part of
one tutorial, we suggest looking at some of the others (and then contacting
us if you are still confused).

**Basic Tutorials:**

.. toctree::
   :maxdepth: 1

   tutorials/Quick-Start.ipynb
   formatting_inputs
   tutorials/OFTI_tutorial.ipynb
   tutorials/MCMC_tutorial.ipynb

**Advanced Tutorials:**

.. toctree::
   :maxdepth: 1

   tutorials/RV_MCMC_Tutorial.ipynb
   tutorials/Multiplanet_Tutorial.ipynb
   tutorials/Modifying_Priors.ipynb
   tutorials/Plotting_tutorial.ipynb
   tutorials/MCMC_vs_OFTI.ipynb
   tutorials/Modifying_MCMC_initial_positions.ipynb


